#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-accessor-transformers
version:              0.2.1.8
visibility:           public
id:                   data-accessor-transformers-0.2.1.8-6r0kpDeHJBMLvIfuEDQcPJ
key:                  data-accessor-transformers-0.2.1.8-6r0kpDeHJBMLvIfuEDQcPJ
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  9883483e5501630b7e2345dc8ea21a18
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/data-accessor-transformers-0.2.1.8

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/data-accessor-transformers-0.2.1.8

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/data-accessor-transformers-0.2.1.8

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-accessor-transformers
hs-libraries:         HSdata-accessor-transformers-0.2.1.8-6r0kpDeHJBMLvIfuEDQcPJ
depends:
    base-4.18.2.1 data-accessor-0.2.3.1-FDvLi0AqzJhAbd4pJJaN0x
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

